==> back_geolocation-0.0.1.tar.gz: android/src/main/java/com/example/back_geolocation/BackGeolocationPlugin.java <==
package com.example.back_geolocation;

import androidx.annotation.NonNull;

import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.os.StrictMode;
import android.util.Log;
import android.widget.Toast;


import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;


import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.UnsupportedEncodingException;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLEncoder;
import java.util.HashMap;
import java.util.Map;


/** BackGeolocationPlugin */
public class BackGeolocationPlugin implements FlutterPlugin, MethodCallHandler {
  
  private static Activity context;
  private static MethodChannel methodChannel;
  private static Context con;
  public int PERMISSION_ID = 44;
  double longitudeNetwork, latitudeNetwork;
  double longitudGps, latitudGps;
  String servidor = "";
  String idGenerico = "0";
  LocationManager locationManaer;


  public void coneccionServer(Location location, String server){
    StrictMode.ThreadPolicy policy = new StrictMode.ThreadPolicy.Builder().permitAll().build();
    StrictMode.setThreadPolicy(policy);

    HttpURLConnection urlConnection = null;
    OutputStream out = null;
    InputStream in = null;


    HashMap<String, String> postDataParams = new HashMap<>();
    postDataParams.put("data","prueba");

    try{
      String data = "data=" + server;
      byte[] bytes = data.getBytes("UTF-8");
      URL url = new URL(server);
      urlConnection = (HttpURLConnection) url.openConnection();

      urlConnection.setReadTimeout(15000);
      urlConnection.setConnectTimeout(15000);
      //urlConnection.setDoOutput(true);
      //urlConnection.setRequestProperty("Content-Type", "application/json");
      urlConnection.setRequestMethod("POST");
      urlConnection.setDoInput(true);
      //urlConnection.setRequestProperty("Content-Length", "" + bytes.length);
      urlConnection.setDoOutput(true);
      out = urlConnection.getOutputStream();
      Log.e("ANTES 1", "== " + urlConnection.getResponseCode() );
      Log.e("ANTES 2", "== " + urlConnection.getErrorStream() );

      BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(out, "UTF-8"));
      Log.e("ANTES 3", "== " + urlConnection.getErrorStream() );
      writer.write(getPostDataString(postDataParams));
      Log.e("ANTES 4", "== " + urlConnection.getErrorStream() );
      Log.e("ANTES 4", "++ " + getPostDataString(postDataParams) );
      writer.flush();
      Log.e("ANTES 5", "== " + urlConnection.getErrorStream() );
      writer.close();
      Log.e("ANTES 6", "== " + urlConnection.getErrorStream() );

      //String text = new String(bytes, "UTF-8");

      //out.write(bytes);
      out.close();
      Log.e("ANTES 7", "== " + urlConnection.getErrorStream() );

      in = urlConnection.getInputStream();

      BufferedReader reader = new BufferedReader(new InputStreamReader(in));
      Log.e("ANTES 2", "== " + urlConnection.getResponseCode() );
      String line = null;
      while((line = reader.readLine()) != null){
        Toast toast = Toast.makeText(this.con, "Mensaje dentro del while -- " + line, Toast.LENGTH_SHORT);

        toast.show();
      }
      in.close();

    }catch (Exception e){
      Log.e("ERROR 1", "-- " + e.getMessage());
      Log.e("ERROR 1", "-- " + e.toString());
      //Log.e("ERROR 1", e.);
      Toast toast = Toast.makeText(this.con, "Esto es un error --- 1 -- " + e.getMessage(), Toast.LENGTH_SHORT);
      toast.show();
    }finally{
      if(urlConnection != null) urlConnection.disconnect();
      try{
        if(out != null) out.close();
        if(in != null) in.close();
      }catch(Exception e){
        Log.e("ERROR 2", "--" + e.getMessage());
        Log.e("ERROR 2", "--" + e.toString());
        Toast toast = Toast.makeText(this.con, "Esto es un error --- 2", Toast.LENGTH_SHORT);
        toast.show();
      }
    }
  }

  public void coneccionExterna(Location location){
    StrictMode.ThreadPolicy policy = new StrictMode.ThreadPolicy.Builder().permitAll().build();
    StrictMode.setThreadPolicy(policy);
    try {
      URL url = new URL(servidor);
      HttpURLConnection urlConnection = (HttpURLConnection) url.openConnection();
      HashMap<String, String> postDataParams = new HashMap<>();
      postDataParams.put("id",this.idGenerico);
      postDataParams.put("latitud",""+location.getLatitude());
      postDataParams.put("longitud",""+location.getLongitude());
      try {
        urlConnection.setRequestMethod("POST");
        urlConnection.setDoOutput(true);
        urlConnection.setChunkedStreamingMode(0);
        OutputStream out = new BufferedOutputStream(urlConnection.getOutputStream());

        BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(out, "UTF-8"));
        writer.write(getPostDataString(postDataParams));
        writer.flush();
        ///Log.e("ANTES 5", "== " + urlConnection.getErrorStream() );
        writer.close();

        //out.write("data=hola".getBytes());

        InputStream in = new BufferedInputStream(urlConnection.getInputStream());

        String a =  readStream(in);

        Log.e("AVER PS 1", "??" + a);
      } finally {
        urlConnection.disconnect();
      }
    }catch(Exception e){
      Log.e("Error", "--" + e.getMessage());
      //Log.e("AVER Erro PS 1", "--" + e.getMessage());
      //Log.e("AVER Erro PS 2", "-- " + e.toString());
    }
  }

  private String readStream(InputStream is) {
    try {
      ByteArrayOutputStream bo = new ByteArrayOutputStream();
      int i = is.read();
      while(i != -1) {
        bo.write(i);
        i = is.read();
      }
      return bo.toString();
    } catch (IOException e) {
      return "";
    }
  }

  //private FusedLocationProviderClient fusedLocationClient;


  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    final MethodChannel channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "back_geolocation");
    channel.setMethodCallHandler(new BackGeolocationPlugin(flutterPluginBinding.getApplicationContext(), channel));
  }

  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "back_geolocation");
    channel.setMethodCallHandler(new BackGeolocationPlugin(registrar.activity(), channel));
  }

  public BackGeolocationPlugin(){
  }

  public BackGeolocationPlugin(Context activity, MethodChannel methodChannel){
    this.con = activity;
    //this.context = (Activity) activity;
    this.methodChannel = methodChannel;
    this.methodChannel.setMethodCallHandler(this);
  }

  /*
  public BackGeolocationPlugin(Activity act, MethodChannel methodChannel){
    this.con = activity;
    this.context = (Activity) context;
    this.methodChannel = methodChannel;
    this.methodChannel.setMethodCallHandler(this);
  }
  */

  /*
  public boolean cheackPermision(){
    if(ActivityCompat.checkSelfPermission(con, Manifest.permission.ACCESS_COARSE_LOCATION) == PackageManager.PERMISSION_GRANTED && ActivityCompat.checkSelfPermission(con, Manifest.permission.ACCESS_FINE_LOCATION) == PackageManager.PERMISSION_GRANTED){
      return true;
    }
    return false;
  }
  */
   

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    }
    else if(call.method.equalsIgnoreCase("showAlertDialog")) {
      //LocationManager locationManager = (LocationManager) con.getSystemService(context.LOCATION_SERVICE);
      //locationManager.requestLocationUpdates(LocationManager.GPS_PROVIDER, 0, 0, (LocationListener) con);
      //LocationRequest mLocationRequest = new LocationRequest();
      idGenerico = call.argument("id");
      servidor = call.argument("server");
      //Toast toast = Toast.makeText(this.con, "Este es mi mesaje desde el plugin -- " + idGenerico + "--" + servidor, Toast.LENGTH_SHORT);
      //toast.show();


      LocationManager locationManager = (LocationManager) this.con.getSystemService(Context.LOCATION_SERVICE);
      LocationListener locationListener = new LocationListener() {
        public void onLocationChanged(Location location) {
          // Called when a new location is found by the network location provider.
          verPunto(location);
          coneccionExterna(location);
          //coneccionServer(location, "http://192.168.0.109/PruebaLocalizacion/PruebaLocalizacion/public/hola");
        }

        public void onStatusChanged(String provider, int status, Bundle extras) {}

        public void onProviderEnabled(String provider) {}

        public void onProviderDisabled(String provider) {}
      };

      locationManager.requestLocationUpdates(LocationManager.NETWORK_PROVIDER, 0, 0, locationListener);




    }
    else {
      result.notImplemented();
    }

    //Venia por defecto creado
    /*
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    } else {
      result.notImplemented();
    }
    */
  }

  public void verPunto(Location location){

    //Toast toast2 = Toast.makeText(this.con, location.getLatitude() + " - " + location.getLongitude(), Toast.LENGTH_SHORT);
    //toast2.show();
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
  }

  private String getPostDataString(HashMap<String, String> params) throws UnsupportedEncodingException {

    StringBuilder result = new StringBuilder();
    boolean first = true;
    for(Map.Entry<String, String> entry : params.entrySet()){
      if (first)
        first = false;
      else
        result.append("&");

      result.append(URLEncoder.encode(entry.getKey(), "UTF-8"));
      result.append("=");
      result.append(URLEncoder.encode(entry.getValue(), "UTF-8"));
    }

    return result.toString();
  }


}

==> back_geolocation-0.0.2.tar.gz: android/src/main/java/com/example/back_geolocation/BackGeolocationPlugin.java <==
package com.example.back_geolocation;

import androidx.annotation.NonNull;

import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.os.StrictMode;
import android.util.Log;
import android.widget.Toast;


import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;


import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.UnsupportedEncodingException;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLConnection;
import java.net.URLEncoder;
import java.util.HashMap;
import java.util.Map;


/** BackGeolocationPlugin */
public class BackGeolocationPlugin implements FlutterPlugin, MethodCallHandler {
  
  private static Activity context;
  private static MethodChannel methodChannel;
  private static Context con;
  public int PERMISSION_ID = 44;
  double longitudeNetwork, latitudeNetwork;
  double longitudGps, latitudGps;
  String servidor = "";
  String idGenerico = "0";
  LocationManager locationManaer;


  public void coneccionServer(Location location, String server){
    StrictMode.ThreadPolicy policy = new StrictMode.ThreadPolicy.Builder().permitAll().build();
    StrictMode.setThreadPolicy(policy);

    HttpURLConnection urlConnection = null;
    OutputStream out = null;
    InputStream in = null;


    HashMap<String, String> postDataParams = new HashMap<>();
    postDataParams.put("data","prueba");

    try{
      String data = "data=" + server;
      byte[] bytes = data.getBytes("UTF-8");
      URL url = new URL(server);
      urlConnection = (HttpURLConnection) url.openConnection();

      urlConnection.setReadTimeout(15000);
      urlConnection.setConnectTimeout(15000);
      //urlConnection.setDoOutput(true);
      //urlConnection.setRequestProperty("Content-Type", "application/json");
      urlConnection.setRequestMethod("POST");
      urlConnection.setDoInput(true);
      //urlConnection.setRequestProperty("Content-Length", "" + bytes.length);
      urlConnection.setDoOutput(true);
      out = urlConnection.getOutputStream();
      Log.e("ANTES 1", "== " + urlConnection.getResponseCode() );
      Log.e("ANTES 2", "== " + urlConnection.getErrorStream() );

      BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(out, "UTF-8"));
      Log.e("ANTES 3", "== " + urlConnection.getErrorStream() );
      writer.write(getPostDataString(postDataParams));
      Log.e("ANTES 4", "== " + urlConnection.getErrorStream() );
      Log.e("ANTES 4", "++ " + getPostDataString(postDataParams) );
      writer.flush();
      Log.e("ANTES 5", "== " + urlConnection.getErrorStream() );
      writer.close();
      Log.e("ANTES 6", "== " + urlConnection.getErrorStream() );

      //String text = new String(bytes, "UTF-8");

      //out.write(bytes);
      out.close();
      Log.e("ANTES 7", "== " + urlConnection.getErrorStream() );

      in = urlConnection.getInputStream();

      BufferedReader reader = new BufferedReader(new InputStreamReader(in));
      Log.e("ANTES 2", "== " + urlConnection.getResponseCode() );
      String line = null;
      while((line = reader.readLine()) != null){
        Toast toast = Toast.makeText(this.con, "Mensaje dentro del while -- " + line, Toast.LENGTH_SHORT);

        toast.show();
      }
      in.close();

    }catch (Exception e){
      Log.e("ERROR 1", "-- " + e.getMessage());
      Log.e("ERROR 1", "-- " + e.toString());
      //Log.e("ERROR 1", e.);
      Toast toast = Toast.makeText(this.con, "Esto es un error --- 1 -- " + e.getMessage(), Toast.LENGTH_SHORT);
      toast.show();
    }finally{
      if(urlConnection != null) urlConnection.disconnect();
      try{
        if(out != null) out.close();
        if(in != null) in.close();
      }catch(Exception e){
        Log.e("ERROR 2", "--" + e.getMessage());
        Log.e("ERROR 2", "--" + e.toString());
        Toast toast = Toast.makeText(this.con, "Esto es un error --- 2", Toast.LENGTH_SHORT);
        toast.show();
      }
    }
  }

  public void coneccionExterna(Location location){
    StrictMode.ThreadPolicy policy = new StrictMode.ThreadPolicy.Builder().permitAll().build();
    StrictMode.setThreadPolicy(policy);
    try {
      URL url = new URL(servidor);
      HttpURLConnection urlConnection = (HttpURLConnection) url.openConnection();
      HashMap<String, String> postDataParams = new HashMap<>();
      postDataParams.put("id",this.idGenerico);
      postDataParams.put("latitud",""+location.getLatitude());
      postDataParams.put("longitud",""+location.getLongitude());
      BufferedWriter writer = null;
      OutputStream out = null;
      InputStream in = null;
      try {
        urlConnection.setRequestMethod("POST");
        urlConnection.setDoOutput(true);
        urlConnection.setChunkedStreamingMode(0);
        //urlConnection.setRequestProperty("User-Agent","Mozilla/5.0 ( compatible ) ");
        //urlConnection.setRequestProperty("Accept","*/*");


        out = new BufferedOutputStream(urlConnection.getOutputStream());
        Log.e("ANTES 1", "== " + urlConnection.getResponseCode() );
        Log.e("ANTES 2", "== " + urlConnection.getErrorStream() );

        writer = new BufferedWriter(new OutputStreamWriter(out, "UTF-8"));
        Log.e("ANTES 3", "== " + urlConnection.getErrorStream() );
        writer.write(getPostDataString(postDataParams));
        Log.e("ANTES 4", "== " + getPostDataString(postDataParams) );
        Log.e("ANTES 4", "== " + urlConnection.getErrorStream() );
        Log.e("ANTES 4", "== " + writer.toString());
        writer.flush();
        Log.e("ANTES 5", "== " + urlConnection.getErrorStream() );


        //out.write("data=hola".getBytes());
        //out.write(getPostDataString(postDataParams).getBytes());

        in = new BufferedInputStream(urlConnection.getInputStream());

        String a =  readStream(in);


        Log.e("AVER PS 1", "??" + a);
      }catch(Exception e){
        e.printStackTrace();
        Log.e("Interno", "--" + e.getMessage());
        Log.e("Interno 2", "-- " + e.toString());
      }finally {
        //if(writer != null) writer.close();
        //if(out != null) out.close();
        //if(in != null) in.close();
        //urlConnection.disconnect();
      }
    }catch(Exception e){
      e.printStackTrace();
      Log.e("Error", "--" + e.getMessage());
      Log.e("Error 2", "-- " + e.toString());

      //Log.e("AVER Erro PS 1", "--" + e.getMessage());
      //Log.e("AVER Erro PS 2", "-- " + e.toString());
    }
  }

  public void metodoConexionNuevo(Location location){
    StrictMode.ThreadPolicy policy = new StrictMode.ThreadPolicy.Builder().permitAll().build();
    StrictMode.setThreadPolicy(policy);
    String urlParameters = "id="+this.idGenerico+"&latitud="+location.getLatitude()+"&longitud="+location.getLongitude();
    try{
      URL url = new URL("http://www.backtracking.esy.es/hola");

      URLConnection conn = url.openConnection();

      conn.setDoOutput(true);

      OutputStreamWriter writer = new OutputStreamWriter(conn.getOutputStream());

      writer.write(urlParameters);
      writer.flush();

      String line;
      BufferedReader reader = new BufferedReader(new InputStreamReader(conn.getInputStream()));

      while ((line = reader.readLine()) != null) {
        System.out.println(line);
      }
      writer.close();
      reader.close();
    }catch(Exception e){
      e.printStackTrace();
    }

  }

  private String readStream(InputStream is) {
    try {
      ByteArrayOutputStream bo = new ByteArrayOutputStream();
      int i = is.read();
      while(i != -1) {
        bo.write(i);
        i = is.read();
      }
      return bo.toString();
    } catch (IOException e) {
      return "";
    }
  }

  //private FusedLocationProviderClient fusedLocationClient;


  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    final MethodChannel channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "back_geolocation");
    channel.setMethodCallHandler(new BackGeolocationPlugin(flutterPluginBinding.getApplicationContext(), channel));
  }

  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "back_geolocation");
    channel.setMethodCallHandler(new BackGeolocationPlugin(registrar.activity(), channel));
  }

  public BackGeolocationPlugin(){
  }

  public BackGeolocationPlugin(Context activity, MethodChannel methodChannel){
    this.con = activity;
    //this.context = (Activity) activity;
    this.methodChannel = methodChannel;
    this.methodChannel.setMethodCallHandler(this);
  }

  /*
  public BackGeolocationPlugin(Activity act, MethodChannel methodChannel){
    this.con = activity;
    this.context = (Activity) context;
    this.methodChannel = methodChannel;
    this.methodChannel.setMethodCallHandler(this);
  }
  */

  /*
  public boolean cheackPermision(){
    if(ActivityCompat.checkSelfPermission(con, Manifest.permission.ACCESS_COARSE_LOCATION) == PackageManager.PERMISSION_GRANTED && ActivityCompat.checkSelfPermission(con, Manifest.permission.ACCESS_FINE_LOCATION) == PackageManager.PERMISSION_GRANTED){
      return true;
    }
    return false;
  }
  */
   

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    }
    else if(call.method.equalsIgnoreCase("showAlertDialog")) {
      //LocationManager locationManager = (LocationManager) con.getSystemService(context.LOCATION_SERVICE);
      //locationManager.requestLocationUpdates(LocationManager.GPS_PROVIDER, 0, 0, (LocationListener) con);
      //LocationRequest mLocationRequest = new LocationRequest();
      idGenerico = call.argument("id");
      servidor = call.argument("server");
      //Toast toast = Toast.makeText(this.con, "Este es mi mesaje desde el plugin -- " + idGenerico + "--" + servidor, Toast.LENGTH_SHORT);
      //toast.show();


      LocationManager locationManager = (LocationManager) this.con.getSystemService(Context.LOCATION_SERVICE);
      LocationListener locationListener = new LocationListener() {
        public void onLocationChanged(Location location) {
          // Called when a new location is found by the network location provider.
          //verPunto(location);
          //coneccionExterna(location);
          metodoConexionNuevo(location);
          //coneccionServer(location, "http://192.168.0.109/PruebaLocalizacion/PruebaLocalizacion/public/hola");
        }

        public void onStatusChanged(String provider, int status, Bundle extras) {}

        public void onProviderEnabled(String provider) {}

        public void onProviderDisabled(String provider) {}
      };

      locationManager.requestLocationUpdates(LocationManager.NETWORK_PROVIDER, 0, 0, locationListener);




    }
    else {
      result.notImplemented();
    }

    //Venia por defecto creado
    /*
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    } else {
      result.notImplemented();
    }
    */
  }

  public void verPunto(Location location){

    //Toast toast2 = Toast.makeText(this.con, location.getLatitude() + " - " + location.getLongitude(), Toast.LENGTH_SHORT);
    //toast2.show();
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
  }

  private String getPostDataString(HashMap<String, String> params) throws UnsupportedEncodingException {

    StringBuilder result = new StringBuilder();
    boolean first = true;
    for(Map.Entry<String, String> entry : params.entrySet()){
      if (first)
        first = false;
      else
        result.append("&");

      result.append(URLEncoder.encode(entry.getKey(), "UTF-8"));
      result.append("=");
      result.append(URLEncoder.encode(entry.getValue(), "UTF-8"));
    }

    return result.toString();
  }


}
